@@ -1,4 +1,8 @@
+from typing import Any, Dict, Optional
+
 from django.contrib import admin
+from django.http.request import HttpRequest
+from django.http.response import HttpResponse
 
 from . import views, settings, models
 
@@ -9,10 +13,10 @@ class QueueAdmin(admin.ModelAdmin):
     def has_add_permission(self, request):
         return False  # Hide the admin "+ Add" link for Queues
 
-    def has_change_permission(self, request):
+    def has_change_permission(self, request: HttpRequest, obj: Optional[Any] = None) -> bool:
         return True
 
-    def has_module_permission(self, request):
+    def has_module_permission(self, request: HttpRequest):
         """
         return True if the given request has any permission in the given
         app label.
@@ -23,9 +27,9 @@ class QueueAdmin(admin.ModelAdmin):
         does not restrict access to the add, change or delete views. Use
         `ModelAdmin.has_(add|change|delete)_permission` for that.
         """
-        return request.user.has_module_perms('django_rq')
+        return request.user.has_module_perms('django_rq')  # type: ignore[union-attr]
 
-    def changelist_view(self, request):
+    def changelist_view(self, request: HttpRequest, extra_context: Optional[Dict[str, Any]] = None) -> HttpResponse:
         """The 'change list' admin view for this model."""
         # proxy request to stats view
         return views.stats(request)
