@@ -1,7 +1,7 @@
 import click
 import time
 
-from django.core.management.base import BaseCommand
+from django.core.management.base import BaseCommand, CommandError
 
 from ...utils import get_statistics
 
@@ -11,6 +11,7 @@ class Command(BaseCommand):
     Print RQ statistics
     """
     help = __doc__
+    _separator: str
 
     def add_arguments(self, parser):
         # TODO: convert this to @click.command like rq does
@@ -85,11 +86,11 @@ class Command(BaseCommand):
         if options.get("yaml"):
             try:
                 import yaml
-            except ImportError:
-                click.echo("Aborting. LibYAML is not installed.")
-                return
+            except ImportError as ex:
+                raise CommandError("PyYAML is not installed.") from ex
+
             # Disable YAML alias
-            yaml.Dumper.ignore_aliases = lambda *args: True
+            yaml.Dumper.ignore_aliases = lambda *args: True  # type: ignore[method-assign]
             click.echo(yaml.dump(get_statistics(), default_flow_style=False))
             return
 
