@@ -9,7 +9,10 @@ def get_queue_index(name='default'):
     connection = get_connection(name)
     connection_kwargs = connection.connection_pool.connection_kwargs
     for i in range(0, 100):
-        q = get_queue_by_index(i)
+        try:
+            q = get_queue_by_index(i)
+        except AttributeError:
+            continue
         if q.name == name and q.connection.connection_pool.connection_kwargs == connection_kwargs:
             queue_index = i
             break
