@@ -10,6 +10,7 @@ urlpatterns = [
     re_path(r'^workers/(?P<queue_index>[\d]+)/(?P<key>[-\w\.\:\$]+)/$', views.worker_details, name='rq_worker_details'),
     re_path(r'^queues/(?P<queue_index>[\d]+)/finished/$', views.finished_jobs, name='rq_finished_jobs'),
     re_path(r'^queues/(?P<queue_index>[\d]+)/failed/$', views.failed_jobs, name='rq_failed_jobs'),
+    re_path(r'^queues/(?P<queue_index>[\d]+)/failed/clear/$', views.delete_failed_jobs, name='rq_delete_failed_jobs'),
     re_path(r'^queues/(?P<queue_index>[\d]+)/scheduled/$', views.scheduled_jobs, name='rq_scheduled_jobs'),
     re_path(r'^queues/(?P<queue_index>[\d]+)/started/$', views.started_jobs, name='rq_started_jobs'),
     re_path(r'^queues/(?P<queue_index>[\d]+)/deferred/$', views.deferred_jobs, name='rq_deferred_jobs'),
@@ -32,4 +33,5 @@ urlpatterns = [
     re_path(
         r'^queues/(?P<queue_index>[\d]+)/(?P<job_id>[^/]+)/stop/$', views.stop_job, name='rq_stop_job'
     ),
+    re_path(r'^schedulers/(?P<scheduler_index>[\d]+)/$', views.scheduler_jobs, name='rq_scheduler_jobs'),
 ]
